@@ -122,7 +122,7 @@ async def _op(model, op, reqtype, delete=False, **kwargs):
 def _op_sync(model, op, reqtype, delete=False, **kwargs):
     """Wrapper function to perform a GRPC operation on the model. (non-asyncio)"""
     req = _pb_request(op, reqtype, **kwargs)
-    r = op(req, **kwargs)
+    r = op(req)
     try:
         iterator = iter(r)  # this is to detect whether its a sequence
         r = [x for x in iterator]  # this does network i/o
